function [e,s,time] = daad_transmit(obj,s,file)
%DAAD_TRANSMIT einen Burst bertragen
%   input arguments
%       obj             Data Acquisition Object
%       file            Dateiname
%   output arguments
%       e               komplexwertige Empfangsdaten, Spannung in Volt
%       s               komplexwertige Sendedaten, Spannung in Volt
%       time            Abtastzeitpunkte
%
%   Data Acquisition Toolbox 
%       S. 6-3, 6-12, 6-16
%
%   11.04.2023          T. Weber    

switch obj.UserData
    case 'none'
        % Messwerte aus Datei lesen
        data = load(file,'-ascii');
        time = data(:,1);
        s = data(:,2)+j*data(:,3);
        e = data(:,4)+j*data(:,5);
        
    case 'simideal'
        e = s(:);
        time = (0:numel(e)-1)'/obj.Rate;

        % Messwerte in Datei schreiben
        data = [time,real(s(:)),imag(s(:)),real(e),imag(e)];
        save(file,'data','-ascii');

    case 'simtx'
        % senderseitige IQ-Imbalance
        deltaS = 2; % Gain Imbalance
        phiS = 30*pi/180; % Quadrature Skew
        QS = [deltaS*cos(phiS),0;deltaS*sin(phiS),1];
        
        % Gleichspannungsoffsets
        AS = [0.1;0.2];
        
        % verzerren
        e = QS(1,1)*real(s(:))+QS(1,2)*imag(s(:))+AS(1)+j*QS(2,1)*real(s(:))+j*QS(2,2)*imag(s(:))+j*AS(2); 
        time = (0:numel(e)-1)'/obj.Rate;

        % Messwerte in Datei schreiben
        data = [time,real(s(:)),imag(s(:)),real(e),imag(e)];
        save(file,'data','-ascii');

    case 'simrx'
        % empfngerseitige IQ-Imbalance
        deltaE = 1/sqrt(2); % Gain Imbalance
        phiE = -45*pi/180; % Quadrature Skew
        QE = [deltaE*cos(phiE),deltaE*sin(phiE);0,1];

        % Gleichspannungsoffsets
        AE = [0.2;0.1];
        
        % verzerren
        e = QE(1,1)*real(s(:))+QE(1,2)*imag(s(:))+AE(1)+j*QE(2,1)*real(s(:))+j*QE(2,2)*imag(s(:))+j*AE(2); 
        time = (0:numel(e)-1)'/obj.Rate;

        % Messwerte in Datei schreiben
        data = [time,real(s(:)),imag(s(:)),real(e),imag(e)];
        save(file,'data','-ascii');

    case 'simreal'
        % empfngerseitige IQ-Imbalance
        deltaE = 1/sqrt(2); % Gain Imbalance
        phiE = -45*pi/180; % Quadrature Skew
        QE = [deltaE*cos(phiE),deltaE*sin(phiE);0,1];

        % Gleichspannungsoffsets
        AE = [0.2;0.1];
        
        % senderseitige IQ-Imbalance
        deltaS = 2; % Gain Imbalance
        phiS = 30*pi/180; % Quadrature Skew
        QS = [deltaS*cos(phiS),0;deltaS*sin(phiS),1];
        
        % Gleichspannungsoffsets
        AS = [0.1;0.2];
        
        Q = QE*QS;
        A = QE*AS+AE;
        
        % verzerren
        e = Q(1,1)*real(s(:))+Q(1,2)*imag(s(:))+A(1)+j*Q(2,1)*real(s(:))+j*Q(2,2)*imag(s(:))+j*A(2); 
        time = (0:numel(e)-1)'/obj.Rate;

        % Messwerte in Datei schreiben
        data = [time,real(s(:)),imag(s(:)),real(e),imag(e)];
        save(file,'data','-ascii');

    case 'usb6366'       
        write(obj,[real(s(1)),imag(s(1))]); % zum Vermeiden von Transienten
        
        data = readwrite(obj,[real(s(:)),imag(s(:))],'OutputFormat','Matrix');
        e = data(:,1)+j*data(:,2);
        time = (0:numel(e)-1)'/obj.Rate;
        
        write(obj,[0,0]); % Ausgnge Spannungsfrei

        % Messwerte in Datei schreiben
        data = [time,real(s(:)),imag(s(:)),data];
        save(file,'data','-ascii');

    otherwise
    	error('unsupported data acquisition device');
        
end

end
