%Analyse der empfängerseitigen IQ-Imbalance
%
% Um hier senderseitige IQ-Imbalances zu vermeiden, 
% wird bei den Messungen ein um f frequenzversetztes Oszillatorsignal
% mit einem konstanten Sendesignal moduliert.
%
%   03.05.2023          T. Weber    

close all;
clear;

daad = 'none'; % SELECT YOUR DATA ACQUISITION DEVICE HERE

fs = 2e6; % Abtastrate
f = 5e-3; % auf fs normierte Frequenz des Testsignals
k = 200001; % Anzahl der Abtastwerte

% Verbindung zum Datenerfassungsgerät aufbauen
obj = daad_connect(daad);

fs = daad_parameters(obj,fs);

% 1 mW total ergeben nach Dämpfung um 10 dB 
% eine totale Mischereingangsleistung von -10 dBm
% 1 mW entspricht sqrt(1e-3*50) Volt = 0,2236 Volt an 50 Ohm
s = sqrt(1e-3*50)*exp(j*2*pi*f*(0:k-1)); % FÜR SIMULATIONEN
%s = sqrt(1e-3*50)*ones(1,k); % FÜR MESSUNGEN

% Burst übertragen
[e,s,time] = daad_transmit(obj,s,'signal.txt');
fs = (numel(time)-1)/(time(end)-time(1));

% Verbindung zum Datenerfassungsgerät schließen
daad_disconnect(obj);

% Signal zeichnen
figure;
plot(time,abs(e),'r-');
hold on;
plot(time,real(e),'g-');
plot(time,imag(e),'b-');
hold off;

% formatieren
grid on;
xlim([time(1),time(end)]);
xlabel('t/s');
legend('|U(t)|/V','Re(U(t))/V','Im(U(t))/V');

% Spektrum berechnen und zeichnen, Leistungen bezogen auf 1 mW
% 1 mW entspricht sqrt(1e-3*50) Volt = 0,2236 Volt an 50 Ohm
figure;
pwelch(e/sqrt(1e-3*50),gausswin(floor(numel(e)/10),4),[],linspace(-2.5*f*fs,2.5*f*fs,501),fs,'power');

% Spektrum abspeichern
h = findobj(gca,'Type','line');
data = [h.XData(:),h.YData(:)];
save('demodulator.txt','data','-ascii');

% Ortskurve zeichnen
figure;
plot(real(e),imag(e),'b-');

% formatieren
grid on;
axis equal;
axis manual;
xlim([min(real(e)),max(real(e))]);
ylim([min(imag(e)),max(imag(e))]);
xlabel('Re(U)/V');
ylabel('Re(U)/V');

% Referenzsignal
s = sqrt(1e-3*50)*exp(j*2*pi*f*(0:k-1));

% IQ-Imbalance schätzen
[QE,AE,deltaE,phiE,IE] = rxschaetzer(e,s);
save('rximbalance','QE','AE');
20*log10(deltaE) % Gain Imbalance in dB
phiE*180/pi % Quadrature Skew in Grad
10*log10(IE) % Image Rejection in dB

% empfängerseitige IQ-Imbalance kompensieren
e = entzerrer(QE,AE,e);

% Signal zeichnen
figure;
plot(time,abs(e),'r-');
hold on;
plot(time,real(e),'g-');
plot(time,imag(e),'b-');
hold off;

% formatieren
grid on;
xlim([time(1),time(end)]);
xlabel('t/s');
legend('|U(t)|/V','Re(U(t))/V','Im(U(t))/V');

% Spektrum berechnen und zeichnen, Leistungen bezogen auf 1 mW
% 1 mW entspricht sqrt(1e-3*50) Volt = 0,2236 Volt an 50 Ohm
figure;
pwelch(e/sqrt(1e-3*50),gausswin(floor(numel(e)/10),4),[],linspace(-2.5*f*fs,2.5*f*fs,501),fs,'power');

% Spektrum abspeichern
h = findobj(gca,'Type','line');
data = [h.XData(:),h.YData(:)];
save('demodulatorentzerrt.txt','data','-ascii');

% Ortskurve zeichnen
figure;
plot(real(e),imag(e),'b-');

% formatieren
grid on;
axis equal;
axis manual;
xlim([min(real(e)),max(real(e))]);
ylim([min(imag(e)),max(imag(e))]);
xlabel('Re(U)/V');
ylabel('Re(U)/V');
